from __future__ import absolute_import

import os
import tempfile
import time
import unittest

try:
    import mock
except ImportError:
    from unittest import mock

import yatts.args
import yatts.yatts


class TestYatts(unittest.TestCase):
    def setUp(self):
        pass

    @mock.patch('sys.stdin', ['test string'])
    def test_read_stdin(self):
        s = yatts.yatts.read()
        self.assertEqual(s, 'test string')

    def test_parser(self):
        parser = yatts.args.setup()
        self.assertTrue(parser)

    def test_parser_args_empty(self):
        args = yatts.args.parse([])
        self.assertEqual(args.fout, None)
        self.assertEqual(args.file, ['-'])

    def test_parser_args_with_values(self):
        args = yatts.args.parse(['--fout', 'test.file'])
        self.assertEquals(args.fout, 'test.file')
        self.assertEqual(args.file, ['-'])

        args = yatts.args.parse(['file.in'])
        self.assertEquals(args.file, ['file.in'])

    def tearDown(self):
        pass


class TestTTS(unittest.TestCase):
    def setUp(self):
        self.f = os.path.join(tempfile.gettempdir(), 'yatts_test.mp3')

    def test_langs(self):
        for lang in yatts.yatts.languages._tts.keys():
            tts = yatts.yatts.google.TTS(text='Hello',
                                         language='en', translate_to=lang)
            segments = [segment for segment in tts]
            self.assertTrue(segments[0].text)
            self.assertTrue(len(segments[0].audio))

    def test_stop(self):
        text = "Hello, this is a test.  "
        text += text * int((1000/len(text)))
        tts = yatts.yatts.google.TTS(text=text, buffer_size=2)
        tts.next()
        tts.stop()
        time.sleep(1.0)
        self.assertTrue(all([tts._stop, tts.stopped]))

    def test_stop_and_save(self):
        text = "Hello, this is a test.  "
        text += text * int((200/len(text)))
        tts = yatts.yatts.google.TTS(text=text, buffer_size=2)
        tts.next()
        tts.save(self.f)
        self.assertEquals(len(tts._cached_segments), len(tts.wrapped_text))


    def test_save(self):
        text = "Hello, this is a test.  "
        text += text * int((200/len(text)))
        tts = yatts.yatts.google.TTS(text=text, buffer_size=2)
        tts.save(self.f)
        self.assertTrue(os.path.getsize(self.f) > 0)

    def tearDown(self):
        if os.path.isfile(self.f):
            os.remove(self.f)


if __name__ == '__main__':
    unittest.main()
