from __future__ import absolute_import

import sys
from glob import glob

import yatts.args
import yatts.config
import yatts.google as google
import yatts.languages as languages


def setup_languages(args, config):
    """Sets up the default and language to translate to."""
    lang = args.lang or config.get('language', 'en')
    translate_to = (args.translate_to_lang or
                    config.get('translate_to_lang', None))
    return (lang, translate_to)


def setup_proxy(args, config):
    """Builds proxy dict."""
    proxy = {}
    http_proxy = args.http_proxy or config.get('http_proxy', None)
    if http_proxy:
        proxy['http'] = http_proxy

    return proxy


def read(fname='-'):
    """Read from a file or stdin

    If fname is - or a space, input is read from stdin.  If a file name is
    passed in fname, the file will be read and the contents returned.
    """
    s = ''
    if fname.strip() in ['-', '']:
        for line in sys.stdin:
            s += line
    else:
        with open(fname) as fin:
            s = fin.read()

    return s


def load_text(args):
    """Load text from stdin or from one ore more files."""
    if not sys.stdin.isatty():
        text = read('-')
    else:
        flatten = lambda list_of_lists: sum(list_of_lists, [])
        text = '\n'.join(map(read, flatten(map(glob, args.file))))

    return text


def main():
    args = yatts.args.parse()
    if args.language_codes:
        languages.display()
        quit()

    config = yatts.config.load(args.config_file)

    gtts = google.TTS(load_text(args),
                      *setup_languages(args, config),
                      proxy=setup_proxy(args, config))

    audio = ''.join([segment.audio for segment in gtts])

    write = lambda writer, s: writer.write(s)
    if not sys.stdout.isatty():
        write(sys.stdout, audio)
    elif args.fout:
        with open(args.fout, 'wb') as fout:
            write(fout, audio)


if __name__ == '__main__':
    main()
